
Deny access from remote resources or systems
-------

**Description:**

You should always fend of remote connections with untrusted systems/resources which try to 
connect to your application in order to prevent connecting to malicious systems that try 
to attack your application.


**Solution:**

Since this is very difficult to achieve on application level we recommend implementing 
EGRESS firewall rules.

	